==> qgis_2.0.1.orig.tar.bz2: qgis-2.0.1/src/app/qgssvgannotationdialog.h <==
/***************************************************************************
                              qgssvgannotationdialog.h
                              ------------------------
  begin                : November, 2012
  copyright            : (C) 2012 by Marco Hugentobler
  email                : marco dot hugentobler at sourcepole dot ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSSVGANNOTATIONDIALOG_H
#define QGSSVGANNOTATIONDIALOG_H

#include "ui_qgsformannotationdialogbase.h"

class QgsSvgAnnotationItem;
class QgsAnnotationWidget;

class QgsSvgAnnotationDialog: public QDialog, private Ui::QgsFormAnnotationDialogBase
{
    Q_OBJECT
  public:
    QgsSvgAnnotationDialog( QgsSvgAnnotationItem* item, QWidget * parent = 0, Qt::WindowFlags f = 0 );
    ~QgsSvgAnnotationDialog();

  private slots:
    void on_mBrowseToolButton_clicked();
    void applySettingsToItem();
    void deleteItem();

  private:
    QgsSvgAnnotationDialog(); //forbidden

    QgsSvgAnnotationItem* mItem;
    QgsAnnotationWidget* mEmbeddedWidget;
};

#endif // QGSSVGANNOTATIONDIALOG_H

==> qgis_2.8.6+dfsg.orig.tar.bz2: qgis-2.8.6/src/app/qgssvgannotationdialog.h <==
/***************************************************************************
                              qgssvgannotationdialog.h
                              ------------------------
  begin                : November, 2012
  copyright            : (C) 2012 by Marco Hugentobler
  email                : marco dot hugentobler at sourcepole dot ch
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSSVGANNOTATIONDIALOG_H
#define QGSSVGANNOTATIONDIALOG_H

#include "ui_qgsformannotationdialogbase.h"

class QgsSvgAnnotationItem;
class QgsAnnotationWidget;

class APP_EXPORT QgsSvgAnnotationDialog: public QDialog, private Ui::QgsFormAnnotationDialogBase
{
    Q_OBJECT
  public:
    QgsSvgAnnotationDialog( QgsSvgAnnotationItem* item, QWidget * parent = 0, Qt::WindowFlags f = 0 );
    ~QgsSvgAnnotationDialog();

  private slots:
    void on_mBrowseToolButton_clicked();
    void applySettingsToItem();
    void deleteItem();

  private:
    QgsSvgAnnotationDialog(); //forbidden

    QgsSvgAnnotationItem* mItem;
    QgsAnnotationWidget* mEmbeddedWidget;
};

#endif // QGSSVGANNOTATIONDIALOG_H
